@@ -13,7 +13,7 @@ import numpy as np
 from hockey_rink import NHLRink, IIHFRink, NWHLRink
 import matplotlib.pyplot as plt
 import matplotlib.image as mpimg
-from matplotlib.legend_handler import HandlerPathCollection
+from matplotlib.lines import Line2D
 import os
 
 ############################################## Team colors dictionary ##############################################
@@ -346,28 +346,28 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
             if team == good_team:
 
                 legend_elements = [Line2D([0], [0], color = colors_dict['SHOT'], marker = 'o',
-                                    markerfacecolor = colors_dict['GOAL'], label = 'GOAL', markersize = 45),
+                                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 45),
                                     
                                     Line2D([0], [0], marker='o', color = colors_dict['SHOT'], label= 'SHOT',
-                                        markerfacecolor = colors_dict['SHOT'], markersize = 45),
+                                        markerfacecolor = colors[team]['SHOT'], markersize = 16),
 
                                    Line2D([0], [0], marker='o', color = colors_dict['MISS'], label= 'MISS',
-                                    markerfacecolor = colors_dict['MISS'], markersize = 45)]
+                                    markerfacecolor = colors[team]['MISS'], markersize = 16)]
 
-                legend = ax.legend(handles = legend_elements, loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
+                legend = ax.legend(handles = legend_elements, loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
                                     title_fontsize = 16, facecolor = 'white', framealpha = 1,
                                     edgecolor = 'gray').set_zorder(-1)
   
             if team == bad_team:
 
                 legend_elements = [Line2D([0], [0], color = colors_dict['SHOT'], marker = 'o',
-                                    markerfacecolor = colors_dict['GOAL'], label = 'GOAL', markersize = 45),
+                                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 45),
                                     
                                     Line2D([0], [0], marker='o', color = colors_dict['SHOT'], label= 'SHOT',
-                                        markerfacecolor = colors_dict['SHOT'], markersize = 45),
+                                        markerfacecolor = colors[team]['SHOT'], markersize = 45),
 
                                    Line2D([0], [0], marker='o', color = colors_dict['MISS'], label= 'MISS',
-                                    markerfacecolor = colors_dict['MISS'], markersize = 45)]
+                                    markerfacecolor = colors[team]['MISS'], markersize = 45)]
 
                 legend = ax.legend(handles = legend_elements, loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
                                     title_fontsize = 16, facecolor = 'white', framealpha = 1,
